@@ -4,7 +4,6 @@ Types for high level PKCS#11 wrapper.
 This module provides stubs that are overrideen in pkcs11._pkcs11.
 """
 
-import struct
 from threading import RLock
 from binascii import hexlify
 
@@ -16,7 +15,7 @@ from .constants import (
     TokenFlag,
     UserType,
 )
-from .mechanisms import Mechanism
+from .mechanisms import KeyType, Mechanism
 from .exceptions import (
     ArgumentsBad,
     AttributeTypeInvalid,
@@ -361,25 +360,68 @@ class Session:
         """
         raise NotImplementedError()
 
-    def create_domain_parameters(self, key_type, attrs, local=False):
+    def create_domain_parameters(self, key_type, attrs,
+                                 local=False, store=False):
         """
-        Create domain parameters.
+        Create a domain parameters object from known parameters.
 
-        The `local` parameter creates an object that is not created on the
-        HSM. This is useful if you only need the domain parameters to create
-        another object, and do not need a real object in the session.
+        Domain parameters are used for key generation of key types such
+        as DH, DSA and EC.
+
+        You can also generate new parameters using
+        :meth:`generate_domain_parameters`.
+
+        The `local` parameter creates a Python object that is not created on
+        the HSM (its object handle will be unset). This is useful if you only
+        need the domain parameters to create another object, and do not need a
+        real PKCS #11 object in the session.
+
+        .. warning::
+
+            Domain parameters have no id or labels. Storing them is possible
+            but be aware they may be difficult to retrieve.
 
         :param KeyType key_type: Key type these parameters are for
-        :param dict(Attribute,*): Domain parameters (specific tp `key_type`)
-        :param local: if True, do not write these to the HSM.
+        :param dict(Attribute,*) attrs: Domain parameters
+            (specific tp `key_type`)
+        :param local: if True, do not transfer parameters to the HSM.
+        :param store: if True, store these parameters permanently in the HSM.
         :rtype: DomainParameters
         """
 
         raise NotImplementedError()
 
-    def generate_key(self, key_type, key_length,
+    def generate_domain_parameters(self, key_type, param_length, store=False,
+                                   mechanism=None, mechanism_param=None,
+                                   template=None):
+        """
+        Generate domain parameters.
+
+        See :meth:`create_domain_parameters` for creating domain parameter
+        objects from known parameters.
+
+        See :meth:`generate_key` for documentation on mechanisms and templates.
+
+        .. warning::
+
+            Domain parameters have no id or labels. Storing them is possible
+            but be aware they may be difficult to retrieve.
+
+        :param KeyType key_type: Key type these parameters are for
+        :param int params_length: Size of the parameters (e.g. prime length)
+            in bits.
+        :param store: Store these parameters in the HSM
+        :param Mechanism mechanism: Optional generation mechanism (or default)
+        :param bytes mechanism_param: Optional mechanism parameter.
+        :param dict(Attribute,*) template: Optional additional attributes.
+        :rtype: DomainParameters
+        """
+
+        raise NotImplementedError()
+
+    def generate_key(self, key_type, key_length=None,
                      id=None, label=None,
-                     store=True, capabilities=None,
+                     store=False, capabilities=None,
                      mechanism=None, mechanism_param=None,
                      template=None):
         """
@@ -415,17 +457,13 @@ class Session:
         """
         raise NotImplementedError()
 
-    def generate_keypair(self, key_type, key_length,
-                         id=None, label=None,
-                         store=True, capabilities=None,
-                         mechanism=None, mechanism_param=None,
-                         public_template=None, private_template=None):
+    def generate_keypair(self, key_type, key_length=None, **kwargs):
         """
         Generate a asymmetric keypair (e.g. RSA).
 
         See :meth:`generate_key` for more information.
 
-        :param KeyType key_type: Key type (e.g. KeyType.AES)
+        :param KeyType key_type: Key type (e.g. KeyType.DSA)
         :param int key_length: Key length in bits (e.g. 256).
         :param bytes id: Key identifier.
         :param str label: Key label.
@@ -437,7 +475,16 @@ class Session:
 
         :rtype: (PublicKey, PrivateKey)
         """
-        raise NotImplementedError()
+        if key_type is KeyType.DSA:
+            if key_length is None:
+                raise ArgumentsBad("Must specify `key_length`")
+
+            params = self.generate_domain_parameters(key_type, key_length)
+
+            return params.generate_keypair(**kwargs)
+        else:
+            return self._generate_keypair(key_type, key_length=key_length,
+                                          **kwargs)
 
     def seed_random(self, seed):
         """
@@ -651,6 +698,10 @@ class PublicKey(Key):
     """
     A PKCS#11 :attr:`pkcs11.constants.ObjectClass.PUBLIC_KEY` object
     (asymmetric public key).
+
+    RSA private keys can be imported and exported from PKCS#1 DER-encoding
+    using :func:`pkcs11.util.rsa.decode_rsa_public_key` and
+    :func:`pkcs11.util.rsa.encode_rsa_public_key` respectively.
     """
 
     object_class = ObjectClass.PUBLIC_KEY
@@ -665,6 +716,14 @@ class PrivateKey(Key):
     """
     A PKCS#11 :attr:`pkcs11.constants.ObjectClass.PRIVATE_KEY` object
     (asymmetric private key).
+
+    RSA private keys can be imported from PKCS#1 DER-encoding using
+    :func:`pkcs11.util.rsa.decode_rsa_private_key`.
+
+    .. warning::
+
+        Private keys imported directly, rather than unwrapped from a trusted
+        private key should be considered insecure.
     """
 
     object_class = ObjectClass.PRIVATE_KEY
@@ -675,6 +734,30 @@ class PrivateKey(Key):
         return len(self[Attribute.MODULUS]) * 8
 
 
+class Certificate(Object):
+    """
+    A PKCS#11 :attr:`pkcs11.constants.ObjectClass.CERTIFICATE` object.
+
+    PKCS#11 is limited in its handling of certificates, and does not
+    provide features like parsing of X.509 etc. These should be handled in
+    an external library. PKCS#11 will not set attributes on the certificate
+    based on the `VALUE`.
+
+    :func:`pkcs11.util.x509.decode_x509_certificate` will extract attributes
+    from a certificate to create the object.
+    """
+    object_class = ObjectClass.CERTIFICATE
+
+    @property
+    def certificate_type(self):
+        """
+        The type of certificate.
+
+        :rtype: CertificateType
+        """
+        return self[Attribute.CERTIFICATE_TYPE]
+
+
 class EncryptMixin(Object):
     """
     This :class:`Object` supports the encrypt capability.
