@@ -4,13 +4,28 @@ PKCS#11 Elliptic Curve Cryptography.
 
 import base64
 
-from pkcs11 import Attribute, KeyType, KDF
+from pyasn1_modules.rfc3279 import prime256v1
+
+from pkcs11 import Attribute, KeyType, KDF, Mechanism
+from pkcs11.util.ec import encode_named_curve_parameters
 
 from . import TestCase, Not
 
 
 @Not.nfast  # No ECC on our nfast device
 class ECCTests(TestCase):
+    def test_sign(self):
+        parameters = self.session.create_domain_parameters(KeyType.EC, {
+            Attribute.EC_PARAMS: encode_named_curve_parameters(prime256v1)
+        }, local=True)
+
+        pub, priv = parameters.generate_keypair()
+
+        mechanism = Mechanism.ECDSA  # SoftHSMv2 doesn't support ECDSA_SHA512
+        data = b'HI BOB!'
+        ecdsa = priv.sign(data, mechanism=mechanism)
+        self.assertTrue(pub.verify(data, ecdsa, mechanism=mechanism))
+
     def test_derive_key(self):
         # DER encoded EC params from OpenSSL
         # openssl ecparam -out ec_param.der -name prime192v1
